#pragma once

#include <string>
#include <vector>

namespace serial
{

    /*!
     * Enumeration defines the possible bytesizes for the serial port.
     */
    typedef enum
    {
        fivebits = 5,
        sixbits = 6,
        sevenbits = 7,
        eightbits = 8, bits_err = -1
    } bytesize_t;

    /*!
     * Enumeration defines the possible parity types for the serial port.
     */
    typedef enum
    {
        parity_none = 0,
        parity_odd = 1,
        parity_even = 2,
        parity_mark = 3,
        parity_space = 4, parity_err = -1
    } parity_t;

    /*!
     * Enumeration defines the possible stopbit types for the serial port.
     */
    typedef enum
    {
        stopbits_one = 1,
        stopbits_two = 2,
        stopbits_one_point_five, stopbits_err = -1
    } stopbits_t;

    /*!
     * Enumeration defines the possible flowcontrol types for the serial port.
     */
    typedef enum
    {
        flowcontrol_none = 0,
        flowcontrol_software,
        flowcontrol_hardware
    } flowcontrol_t;
	//-----------------------------------------------------------------------------
	//	ComOptions
	class ComOptions
	{
	public:

		//	 rs-порт.
		std::string port;

		//	Скорость.
		int baud_rate;

		//	количество бит в байте
		serial::bytesize_t bytesize;

		//	контроль четности
		serial::parity_t parity;

		//	количество стоп-бит
		serial::stopbits_t stopbits;

		//	управление обменом
		serial::flowcontrol_t flowcontrol;

		//	def ctor
		ComOptions ( );

		//	ctor
		ComOptions ( const std::string& port, const int baude_rate, const std::string& co );

		//	анализ
		void parse ( const std::string& co );

		//	валидировать
		bool validate ( );
	};

} /* namespace serial */
